@@ -2,10 +2,11 @@ __all__ = [
     'OnnxNonMaxSuppression',
 ]
 
+from typing import Any
+from typing import Dict
 from typing import Optional
 
 import torch
-import torch._C as torch_C
 import torchvision
 from torch import nn
 
@@ -13,17 +14,53 @@ from onnx2torch.node_converters.registry import add_converter
 from onnx2torch.onnx_graph import OnnxGraph
 from onnx2torch.onnx_node import OnnxNode
 from onnx2torch.utils.common import OperationConverterResult
+from onnx2torch.utils.common import get_onnx_version
 from onnx2torch.utils.common import onnx_mapping_from_node
-from onnx2torch.utils.custom_export_to_onnx import CustomExportToOnnx
+from onnx2torch.utils.custom_export_to_onnx import DefaultExportToOnnx
 from onnx2torch.utils.custom_export_to_onnx import OnnxToTorchModuleWithCustomExport
 
 
 class OnnxNonMaxSuppression(nn.Module, OnnxToTorchModuleWithCustomExport):  # pylint: disable=missing-class-docstring
-    def __init__(self, center_point_box: bool = False):
+    def __init__(self, center_point_box: int = 0):
         super().__init__()
-        self.center_point_box = center_point_box
+        self._center_point_box = center_point_box
 
-    def _do_forward(
+    def _onnx_attrs(self, opset_version: int) -> Dict[str, Any]:
+        return {'center_point_box_i': self._center_point_box}
+
+    def forward(  # pylint: disable=missing-function-docstring
+        self,
+        boxes: torch.Tensor,
+        scores: torch.Tensor,
+        max_output_boxes_per_class: Optional[torch.Tensor] = None,
+        iou_threshold: Optional[torch.Tensor] = None,
+        score_threshold: Optional[torch.Tensor] = None,
+    ) -> torch.Tensor:
+        forward_lambda = lambda: self._nms(boxes, scores, max_output_boxes_per_class, iou_threshold, score_threshold)
+
+        if torch.onnx.is_in_onnx_export():
+            if max_output_boxes_per_class is None:
+                max_output_boxes_per_class = torch.tensor([0], dtype=torch.int64)
+            if iou_threshold is None:
+                iou_threshold = torch.tensor([0.0], dtype=torch.float32)
+            if score_threshold is None:
+                score_threshold = torch.tensor([0.0], dtype=torch.float32)
+
+            onnx_attrs = self._onnx_attrs(opset_version=get_onnx_version())
+            return DefaultExportToOnnx.export(
+                forward_lambda,
+                'NonMaxSuppression',
+                boxes,
+                scores,
+                max_output_boxes_per_class,
+                iou_threshold,
+                score_threshold,
+                onnx_attrs,
+            )
+
+        return forward_lambda()
+
+    def _nms(
         self,
         boxes: torch.Tensor,
         scores: torch.Tensor,
@@ -47,7 +84,7 @@ class OnnxNonMaxSuppression(nn.Module, OnnxToTorchModuleWithCustomExport):  # py
                 confidence_indexes = confidence_mask.nonzero(as_tuple=False).squeeze(1)
 
                 filtered_batch_boxes = batch_boxes[confidence_indexes]
-                if self.center_point_box:
+                if self._center_point_box:
                     filtered_batch_boxes = torchvision.ops.box_convert(
                         filtered_batch_boxes,
                         in_fmt='cxcywh',
@@ -69,58 +106,12 @@ class OnnxNonMaxSuppression(nn.Module, OnnxToTorchModuleWithCustomExport):  # py
 
         return torch.tensor(out, dtype=torch.int64, device=boxes.device)
 
-    def forward(  # pylint: disable=missing-function-docstring
-        self,
-        boxes: torch.Tensor,
-        scores: torch.Tensor,
-        max_output_boxes_per_class: Optional[torch.Tensor] = None,
-        iou_threshold: Optional[torch.Tensor] = None,
-        score_threshold: Optional[torch.Tensor] = None,
-    ) -> torch.Tensor:
-        forward_lambda = lambda: self._do_forward(
-            boxes, scores, max_output_boxes_per_class, iou_threshold, score_threshold
-        )
-        if torch.onnx.is_in_onnx_export():
-            if max_output_boxes_per_class is None:
-                max_output_boxes_per_class = torch.tensor([0], dtype=torch.int64)
-            if iou_threshold is None:
-                iou_threshold = torch.tensor([0.0], dtype=torch.float32)
-            if score_threshold is None:
-                score_threshold = torch.tensor([0.0], dtype=torch.float32)
-
-            return _NmsExportToOnnx.set_forward_and_apply(
-                forward_lambda,
-                boxes,
-                scores,
-                max_output_boxes_per_class,
-                iou_threshold,
-                score_threshold,
-                int(self.center_point_box),
-            )
-
-        return forward_lambda()
-
-
-class _NmsExportToOnnx(CustomExportToOnnx):  # pylint: disable=abstract-method
-    @staticmethod
-    def symbolic(graph: torch_C.Graph, *args) -> torch_C.Value:
-        boxes, scores, max_output_boxes_per_class, iou_threshold, score_threshold, center_point_box = args
-        return graph.op(
-            'NonMaxSuppression',
-            boxes,
-            scores,
-            max_output_boxes_per_class,
-            iou_threshold,
-            score_threshold,
-            center_point_box_i=center_point_box,
-            outputs=1,
-        )
-
 
 @add_converter(operation_type='NonMaxSuppression', version=10)
 @add_converter(operation_type='NonMaxSuppression', version=11)
 def _(node: OnnxNode, graph: OnnxGraph) -> OperationConverterResult:  # pylint: disable=unused-argument
+    center_point_box = node.attributes.get('center_point_box', 0)
     return OperationConverterResult(
-        torch_module=OnnxNonMaxSuppression(center_point_box=node.attributes.get('center_point_box', 0) == 1),
+        torch_module=OnnxNonMaxSuppression(center_point_box=center_point_box),
         onnx_mapping=onnx_mapping_from_node(node),
     )
