@@ -3,7 +3,6 @@ __all__ = [
 ]
 
 import torch
-import torch._C as torch_C
 from torch import nn
 
 from onnx2torch.node_converters.registry import add_converter
@@ -11,7 +10,7 @@ from onnx2torch.onnx_graph import OnnxGraph
 from onnx2torch.onnx_node import OnnxNode
 from onnx2torch.utils.common import OperationConverterResult
 from onnx2torch.utils.common import onnx_mapping_from_node
-from onnx2torch.utils.custom_export_to_onnx import CustomExportToOnnx
+from onnx2torch.utils.custom_export_to_onnx import DefaultExportToOnnx
 from onnx2torch.utils.custom_export_to_onnx import OnnxToTorchModuleWithCustomExport
 
 
@@ -24,21 +23,14 @@ class OnnxTile(nn.Module, OnnxToTorchModuleWithCustomExport):  # pylint: disable
         # torch.tile(input_tensor, repeats) is not supported for exporting
         forward_lambda = lambda: input_tensor.repeat(torch.Size(repeats))
         if torch.onnx.is_in_onnx_export():
-            return _TileExportToOnnx.set_forward_and_apply(forward_lambda, input_tensor, repeats)
+            return DefaultExportToOnnx.export(forward_lambda, 'Tile', input_tensor, repeats, {})
 
         return forward_lambda()
 
 
-class _TileExportToOnnx(CustomExportToOnnx):  # pylint: disable=abstract-method
-    @staticmethod
-    def symbolic(graph: torch_C.Graph, *args) -> torch_C.Value:
-        return graph.op('Tile', *args, outputs=1)
-
-
 @add_converter(operation_type='Tile', version=6)
 @add_converter(operation_type='Tile', version=13)
 def _(node: OnnxNode, graph: OnnxGraph) -> OperationConverterResult:  # pylint: disable=unused-argument
-
     return OperationConverterResult(
         torch_module=OnnxTile(),
         onnx_mapping=onnx_mapping_from_node(node=node),
